==> jc-1.4.0.tar.gz: gnu/regexp/RETokenChar.h <==
// final class gnu.regexp.RETokenChar

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class a1e41c737bd7b79 gnu_regexp_RETokenChar
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenChar_H_
#define _JC_gnu_regexp_RETokenChar_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_gnu_regexp_REToken$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenChar$sub_refs	_jc_gnu_regexp_RETokenChar$sub_refs;
typedef struct _jc_gnu_regexp_RETokenChar$sub_nonrefs	_jc_gnu_regexp_RETokenChar$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenChar$refs	_jc_gnu_regexp_RETokenChar$refs;
typedef struct _jc_gnu_regexp_RETokenChar$nonrefs	_jc_gnu_regexp_RETokenChar$nonrefs;
typedef struct _jc_gnu_regexp_RETokenChar$object	_jc_gnu_regexp_RETokenChar$object;

typedef const struct _jc_gnu_regexp_RETokenChar$vmethods	_jc_gnu_regexp_RETokenChar$vmethods;
typedef const struct _jc_gnu_regexp_RETokenChar$vtable	_jc_gnu_regexp_RETokenChar$vtable;
typedef const struct _jc_gnu_regexp_RETokenChar$vtype	_jc_gnu_regexp_RETokenChar$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenChar$method$_init$09da8d55b8bf6950(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, jint, jchar, jboolean);

// Virtual methods
extern jboolean _jc_gnu_regexp_RETokenChar$method$chain$97914796563ab628(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_gnu_regexp_REToken$object *);
extern void _jc_gnu_regexp_RETokenChar$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_java_lang_StringBuffer$object *);
extern jint _jc_gnu_regexp_RETokenChar$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *);
extern jboolean _jc_gnu_regexp_RETokenChar$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$chain$97914796563ab628;
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenChar$vmethods {
	jboolean	(*chain$97914796563ab628)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_gnu_regexp_REToken$object *);
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_java_lang_StringBuffer$object *);
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenChar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenChar$vmethods	gnu_regexp_RETokenChar;
};

// Vtype
struct _jc_gnu_regexp_RETokenChar$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenChar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenChar$sub_refs {
	_jc_char_array	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenChar$refs {
    _jc_gnu_regexp_RETokenChar$sub_refs	gnu_regexp_RETokenChar;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenChar$sub_nonrefs {
	jboolean	insens;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenChar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenChar$sub_nonrefs	gnu_regexp_RETokenChar;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenChar$object {
	_jc_gnu_regexp_RETokenChar$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenChar$vtype	*vtype;
	_jc_gnu_regexp_RETokenChar$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenChar$vtype _jc_gnu_regexp_RETokenChar$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenChar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenChar$class_object;

#endif	/* _JC_gnu_regexp_RETokenChar_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenChar.h <==
// final class gnu.regexp.RETokenChar

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class a1e41c737bd7b79 gnu_regexp_RETokenChar
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenChar_H_
#define _JC_gnu_regexp_RETokenChar_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_gnu_regexp_REToken$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenChar$sub_refs	_jc_gnu_regexp_RETokenChar$sub_refs;
typedef struct _jc_gnu_regexp_RETokenChar$sub_nonrefs	_jc_gnu_regexp_RETokenChar$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenChar$refs	_jc_gnu_regexp_RETokenChar$refs;
typedef struct _jc_gnu_regexp_RETokenChar$nonrefs	_jc_gnu_regexp_RETokenChar$nonrefs;
typedef struct _jc_gnu_regexp_RETokenChar$object	_jc_gnu_regexp_RETokenChar$object;

typedef const struct _jc_gnu_regexp_RETokenChar$vmethods	_jc_gnu_regexp_RETokenChar$vmethods;
typedef const struct _jc_gnu_regexp_RETokenChar$vtable	_jc_gnu_regexp_RETokenChar$vtable;
typedef const struct _jc_gnu_regexp_RETokenChar$vtype	_jc_gnu_regexp_RETokenChar$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenChar$method$_init$09da8d55b8bf6950(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, jint, jchar, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_regexp_RETokenChar$method$chain$97914796563ab628(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_gnu_regexp_REToken$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RETokenChar$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_RETokenChar$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenChar$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$chain$97914796563ab628;
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenChar$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenChar$vmethods {
	jboolean	(*chain$97914796563ab628)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_gnu_regexp_REToken$object *) _JC_JCNI_ATTR;
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenChar$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenChar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenChar$vmethods	gnu_regexp_RETokenChar;
};

// Vtype
struct _jc_gnu_regexp_RETokenChar$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenChar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenChar$sub_refs {
	_jc_char_array	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenChar$refs {
    _jc_gnu_regexp_RETokenChar$sub_refs	gnu_regexp_RETokenChar;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenChar$sub_nonrefs {
	jboolean	insens;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenChar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenChar$sub_nonrefs	gnu_regexp_RETokenChar;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenChar$object {
	_jc_gnu_regexp_RETokenChar$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenChar$vtype	*vtype;
	_jc_gnu_regexp_RETokenChar$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenChar$vtype _jc_gnu_regexp_RETokenChar$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenChar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenChar$class_object;

#endif	/* _JC_gnu_regexp_RETokenChar_H_ */
